==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_YOURNAME","Zure izena");

define("_OK","Bidali");
define("_COMMENT","komentarioa");

define("_CONFIGURE","Konfiguratu");
define("_LOGINCREATE","Zure Kontura sartu");
define("_THRESHOLD","Puntuak");
define("_NOCOMMENTS","Komentariorik gabe");
define("_NESTED","Gaika lotu");
define("_FLAT","Sartu diren ordenean");
define("_THREAD","Hariagatik");
define("_OLDEST","Zaharrak lehenago");
define("_NEWEST","Berriak lehenago");
define("_HIGHEST","Puntuazio gehien daukatenek lehenago");
define("_COMMENTSWARNING","Bidalitako komentarioak bakoitzaren errespontsabilitatea izango dira, inola ere Sistemako arduradunarenak.");
define("_SCORE","Puntuazioa");


define("_USERINFO","Erabiltzailearen informazioa");
define("_READREST","Komentario guztia irakurri...");
define("_REPLY","Honi erantzun");
define("_REPLYMAIN","Komentarioa bidali");
define("_NOSUBJECT","Gairik gabe");
define("_NOANONCOMMENTS","Komentario anonimoak ez dira onartzen, mesedez <a href=\"user.php\">erregstratu</a> zaitez");
define("_PARENT","Aurrekoa");
define("_ROOT","Erroa/Lehena");

define("_UCOMMENT","Komentarioa");
define("_ALLOWEDHTML","HTML erabili daiteke:");
define("_POSTANON","Anonimo bidalketa");
define("_EXTRANS","Itzuli (html tag-ak testu bihurtu)");
define("_HTMLFORMATED","HTML formatoakin");
define("_PLAINTEXT","Testu laua bakarrik");
define("_ONN","non...");
define("_SUBJECT","Gaia");
define("_SURVEYCOM","Komentarioa inkestara bidali");
define("_SURVEYCOMPRE","Inkestari komentarioak aurrebistatu");
define("_NOTRIGHT","Zeozer ez doia ondo. abisatu sistemako arduradunari. just to keep things from messing up down the road");
define("_DIRECTCOM","Inkestari komentario zuzena . . .");
define("_SENDAMSG","Mezu bat bidali");

define("_PASTSURVEYS","Aurreko Inkestak");



define("_LVOTES","Botoak");
define("_TOTALVOTES","Guztirako Botoak:");
define("_VOTING","Bozketa gela");
define("_OTHERPOLLS","Beste bozketa batzuk");
define("_CURRENTSURVEY","Egungo Inkesta");
define("_CURRENTPOLLRESULTS","Egungo Inkestaren emaitzak");
define("_PREVIEW","Aurrebista");


define("_REFRESH","Birkargatu");
define("_SURVEYS","Inkestak");
define("_ATTACHEDTOARTICLE","- Artikuloari lotuta:");
define("_SURVEYSATTACHED","Artikuloei lotuta dauden inkestak");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-euskara.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_YOURNAME","Zure izena");

define("_OK","Bidali");
define("_COMMENT","komentarioa");

define("_CONFIGURE","Konfiguratu");
define("_LOGINCREATE","Zure Kontura sartu");
define("_THRESHOLD","Puntuak");
define("_NOCOMMENTS","Komentariorik gabe");
define("_NESTED","Gaika lotu");
define("_FLAT","Sartu diren ordenean");
define("_THREAD","Hariagatik");
define("_OLDEST","Zaharrak lehenago");
define("_NEWEST","Berriak lehenago");
define("_HIGHEST","Puntuazio gehien daukatenek lehenago");
define("_COMMENTSWARNING","Bidalitako komentarioak bakoitzaren errespontsabilitatea izango dira, inola ere Sistemako arduradunarenak.");
define("_SCORE","Puntuazioa");


define("_USERINFO","Erabiltzailearen informazioa");
define("_READREST","Komentario guztia irakurri...");
define("_REPLY","Honi erantzun");
define("_REPLYMAIN","Komentarioa bidali");
define("_NOSUBJECT","Gairik gabe");
define("_NOANONCOMMENTS","Komentario anonimoak ez dira onartzen, mesedez <a href=\"user.php\">erregstratu</a> zaitez");
define("_PARENT","Aurrekoa");
define("_ROOT","Erroa/Lehena");

define("_UCOMMENT","Komentarioa");
define("_ALLOWEDHTML","HTML erabili daiteke:");
define("_POSTANON","Anonimo bidalketa");
define("_EXTRANS","Itzuli (html tag-ak testu bihurtu)");
define("_HTMLFORMATED","HTML formatoakin");
define("_PLAINTEXT","Testu laua bakarrik");
define("_ONN","non...");
define("_SUBJECT","Gaia");
define("_SURVEYCOM","Komentarioa inkestara bidali");
define("_SURVEYCOMPRE","Inkestari komentarioak aurrebistatu");
define("_NOTRIGHT","Zeozer ez doia ondo. abisatu sistemako arduradunari. just to keep things from messing up down the road");
define("_DIRECTCOM","Inkestari komentario zuzena . . .");
define("_SENDAMSG","Mezu bat bidali");

define("_PASTSURVEYS","Aurreko Inkestak");



define("_LVOTES","Botoak");
define("_TOTALVOTES","Guztirako Botoak:");
define("_VOTING","Bozketa gela");
define("_OTHERPOLLS","Beste bozketa batzuk");
define("_CURRENTSURVEY","Egungo Inkesta");
define("_CURRENTPOLLRESULTS","Egungo Inkestaren emaitzak");
define("_PREVIEW","Aurrebista");


define("_REFRESH","Birkargatu");
define("_SURVEYS","Inkestak");
define("_ATTACHEDTOARTICLE","- Artikuloari lotuta:");
define("_SURVEYSATTACHED","Artikuloei lotuta dauden inkestak");


?>
